@@ -8,23 +8,31 @@ def bach_patches(
     root,  # '/data/ldap/histopathologic/original_read_only/BACH/ICIAR2018_BACH_Challenge'
     transformation=None,
     pre_transformation=None,
-    split="all",
+    subset="all",
     splitting_seed=69,
     splitting_trainings_percentage=0.8,
     seed=None,
-    patch_size=224,
+    patch_size=None,
     overlapping_percentage=0.0,
 ):
-    manipulators_to_use = [
-        df_manipulators.EditDFImageGrid(patch_size, overlapping_percentage, (1536, 2048))
-    ]
-    if split == "train":
+    if patch_size is not None:
+        manipulators_to_use = [
+            df_manipulators.EditDFImageGrid(patch_size, overlapping_percentage, (1536, 2048))
+        ]
+        data_reader = data_readers.ReadFromImageFile(
+            "Photos/{label}/{file_name}", return_image_size=patch_size
+        )
+    else:
+        manipulators_to_use = []
+        data_reader = data_readers.ReadFromImageFile("Photos/{label}/{file_name}")
+
+    if subset == "train":
         manipulators_to_use.append(
             df_manipulators.RandomFilterByColumnValue(
                 "file_name", splitting_trainings_percentage, mode=0, seed=splitting_seed
             )
         )
-    elif split == "valid":
+    elif subset == "valid":
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -35,7 +43,7 @@ def bach_patches(
                 ),
             ]
         )
-    elif split == "test":
+    elif subset == "test":
         manipulators_to_use.extend(
             [
                 df_manipulators.RandomFilterByColumnValue(
@@ -46,19 +54,19 @@ def bach_patches(
                 ),
             ]
         )
-    elif split == "all":
+    elif subset == "all":
         pass
     else:
         raise NotImplementedError(
-            'The parameter "split" needs to be one of ["train", "valid", "test", "all"].'
+            'The parameter "subset" needs to be one of ["train", "valid", "test", "all"].'
         )
 
-    path_to_csv = os.path.join(root, "Photos/microscopy_ground_truth.csv")
+    path_to_csv = "Photos/microscopy_ground_truth.csv"
     ds = HistoDataset(
         df_creators.CreateDFFromCSV(path_to_csv, header=None, names=["file_name", "label"]),
         root,
         df_manipulators=manipulators_to_use,
-        data_readers="Photos/{label}/{file_name}",
+        data_readers=data_reader,
         feature_readers=data_readers.ReadValueFromCSV(
             r"{label}", encoded_values=["Benign", "InSitu", "Invasive", "Normal"]
         ),
