@@ -175,7 +175,7 @@ def mai_patches(
         )
 
     ds = HistoDataset(
-        os.path.join(root, "data4e.csv"),
+        "data4e.csv",
         root,
         df_manipulators=manipulators_to_use,
         data_readers=readers_to_use,
